use std::str::FromStr;

struct GlobalArgs {
    subcommand: Option<Subcommand>,
}

enum Subcommand {
    Repl,
    Help,
}

impl FromStr for Subcommand {
    type Err = ();

    fn from_str(input: &str) -> Result<Subcommand, Self::Err> {
        // TODO: errors should show similar commands?
        match input {
            "help" => Ok(Subcommand::Help),
            "repl" => Ok(Subcommand::Repl),
            _ => Err(()),
        }
    }
}

fn usage(exit_code: i32) -> ! {
    println!("Hang in there! TODO: Implement help!");
    std::process::exit(exit_code);
}

fn parse_global_args() -> Result<GlobalArgs, lexopt::Error> {
    use lexopt::prelude::*;

    let mut subcommand = None;

    let mut parser = lexopt::Parser::from_env();
    while let Some(arg) = parser.next()? {
        match arg {
            Short('h') | Long("help") => {
                usage(0);
            }
            Value(s) if subcommand.is_none() => {
                subcommand = Some(s.parse()?);
            }
            _ => return Err(arg.unexpected()),
        }
    }

    return Ok(GlobalArgs { subcommand });
}

pub fn run() -> anyhow::Result<()> {
    Ok(())
}
